#!/bin/bash
set -Eeuo pipefail

hurl --toto test_ok/hello/hello.hurl

